/***********************************************************************************************************************************
PostgreSQL Page Interface
***********************************************************************************************************************************/
#include "build.auto.h"

#include <string.h>

#include "postgres/interface/static.vendor.h"

/***********************************************************************************************************************************
Include the page checksum code
***********************************************************************************************************************************/
#include "postgres/interface/pageChecksum.vendor.c.inc"

/**********************************************************************************************************************************/
uint16_t
pgPageChecksum(unsigned char *page, uint32_t blockNo)
{
    return pg_checksum_page((char *)page, blockNo);
}
